aboutsummaryrefslogtreecommitdiffhomepage
path: root/examples/data/uzbl/scripts/session.sh
diff options
context:
space:
mode:
Diffstat (limited to 'examples/data/uzbl/scripts/session.sh')
-rwxr-xr-xexamples/data/uzbl/scripts/session.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/examples/data/uzbl/scripts/session.sh b/examples/data/uzbl/scripts/session.sh
index 22d48a2..1059b5e 100755
--- a/examples/data/uzbl/scripts/session.sh
+++ b/examples/data/uzbl/scripts/session.sh
@@ -1,18 +1,18 @@
#!/bin/sh
# Very simple session manager for uzbl. When called with "endsession" as the
# argument, it'll backup $sessionfile, look for fifos in $fifodir and
# instruct each of them to store their current url in $sessionfile and
# terminate themselves. Run with "launch" as the argument and an instance of
# uzbl will be launched for each stored url. "endinstance" is used internally
# and doesn't need to be called manually at any point.
# Add a line like 'bind quit = /path/to/session.sh endsession' to your config
[ -d ${XDG_DATA_HOME:-$HOME/.local/share}/uzbl ] || exit 1
scriptfile=$0 # this script
-sessionfile=${XDG_DATA_HOME:-$HOME/.local/share}/uzbl/session # the file in which the "session" (i.e. urls) are stored
+sessionfile=${XDG_DATA_HOME:-$HOME/.local/share}/uzbl/browser-session # the file in which the "session" (i.e. urls) are stored
configfile=${XDG_DATA_HOME:-$HOME/.local/share}/uzbl/config # uzbl configuration file
-UZBL="uzbl -c $configfile" # add custom flags and whatever here.
+UZBL="uzbl-browser -c $configfile" # add custom flags and whatever here.
fifodir=/tmp # remember to change this if you instructed uzbl to put its fifos elsewhere
thisfifo="$4"
@@ -1,18 +1,18 @@
#!/bin/sh
-# Very simple session manager for uzbl. When called with "endsession" as the
+# Very simple session manager for uzbl-browser. When called with "endsession" as the
# argument, it'll backup $sessionfile, look for fifos in $fifodir and
# instruct each of them to store their current url in $sessionfile and
@@ -1,18 +1,18 @@
# instruct each of them to store their current url in $sessionfile and
# terminate themselves. Run with "launch" as the argument and an instance of
-# uzbl will be launched for each stored url. "endinstance" is used internally
+# uzbl-browser will be launched for each stored url. "endinstance" is used internally
# and doesn't need to be called manually at any point.
# Add a line like 'bind quit = /path/to/session.sh endsession' to your config